# This file is generated by make.paws. Please do not edit here.
#' @importFrom paws.common get_config new_operation new_request send_request
#' @include dynamodbstreams_service.R
NULL

#' Returns information about a stream, including the current status of the
#' stream, its Amazon Resource Name (ARN), the composition of its shards,
#' and its corresponding DynamoDB table
#'
#' @description
#' Returns information about a stream, including the current status of the stream, its Amazon Resource Name (ARN), the composition of its shards, and its corresponding DynamoDB table.
#'
#' See [https://www.paws-r-sdk.com/docs/dynamodbstreams_describe_stream/](https://www.paws-r-sdk.com/docs/dynamodbstreams_describe_stream/) for full documentation.
#'
#' @param StreamArn &#91;required&#93; The Amazon Resource Name (ARN) for the stream.
#' @param Limit The maximum number of shard objects to return. The upper limit is 100.
#' @param ExclusiveStartShardId The shard ID of the first item that this operation will evaluate. Use
#' the value that was returned for `LastEvaluatedShardId` in the previous
#' operation.
#'
#' @keywords internal
#'
#' @rdname dynamodbstreams_describe_stream
dynamodbstreams_describe_stream <- function(StreamArn, Limit = NULL, ExclusiveStartShardId = NULL) {
  op <- new_operation(
    name = "DescribeStream",
    http_method = "POST",
    http_path = "/",
    paginator = list()
  )
  input <- .dynamodbstreams$describe_stream_input(StreamArn = StreamArn, Limit = Limit, ExclusiveStartShardId = ExclusiveStartShardId)
  output <- .dynamodbstreams$describe_stream_output()
  config <- get_config()
  svc <- .dynamodbstreams$service(config)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.dynamodbstreams$operations$describe_stream <- dynamodbstreams_describe_stream

#' Retrieves the stream records from a given shard
#'
#' @description
#' Retrieves the stream records from a given shard.
#'
#' See [https://www.paws-r-sdk.com/docs/dynamodbstreams_get_records/](https://www.paws-r-sdk.com/docs/dynamodbstreams_get_records/) for full documentation.
#'
#' @param ShardIterator &#91;required&#93; A shard iterator that was retrieved from a previous GetShardIterator
#' operation. This iterator can be used to access the stream records in
#' this shard.
#' @param Limit The maximum number of records to return from the shard. The upper limit
#' is 1000.
#'
#' @keywords internal
#'
#' @rdname dynamodbstreams_get_records
dynamodbstreams_get_records <- function(ShardIterator, Limit = NULL) {
  op <- new_operation(
    name = "GetRecords",
    http_method = "POST",
    http_path = "/",
    paginator = list()
  )
  input <- .dynamodbstreams$get_records_input(ShardIterator = ShardIterator, Limit = Limit)
  output <- .dynamodbstreams$get_records_output()
  config <- get_config()
  svc <- .dynamodbstreams$service(config)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.dynamodbstreams$operations$get_records <- dynamodbstreams_get_records

#' Returns a shard iterator
#'
#' @description
#' Returns a shard iterator. A shard iterator provides information about how to retrieve the stream records from within a shard. Use the shard iterator in a subsequent [`get_records`][dynamodbstreams_get_records] request to read the stream records from the shard.
#'
#' See [https://www.paws-r-sdk.com/docs/dynamodbstreams_get_shard_iterator/](https://www.paws-r-sdk.com/docs/dynamodbstreams_get_shard_iterator/) for full documentation.
#'
#' @param StreamArn &#91;required&#93; The Amazon Resource Name (ARN) for the stream.
#' @param ShardId &#91;required&#93; The identifier of the shard. The iterator will be returned for this
#' shard ID.
#' @param ShardIteratorType &#91;required&#93; Determines how the shard iterator is used to start reading stream
#' records from the shard:
#' 
#' -   `AT_SEQUENCE_NUMBER` - Start reading exactly from the position
#'     denoted by a specific sequence number.
#' 
#' -   `AFTER_SEQUENCE_NUMBER` - Start reading right after the position
#'     denoted by a specific sequence number.
#' 
#' -   `TRIM_HORIZON` - Start reading at the last (untrimmed) stream
#'     record, which is the oldest record in the shard. In DynamoDB
#'     Streams, there is a 24 hour limit on data retention. Stream records
#'     whose age exceeds this limit are subject to removal (trimming) from
#'     the stream.
#' 
#' -   `LATEST` - Start reading just after the most recent stream record in
#'     the shard, so that you always read the most recent data in the
#'     shard.
#' @param SequenceNumber The sequence number of a stream record in the shard from which to start
#' reading.
#'
#' @keywords internal
#'
#' @rdname dynamodbstreams_get_shard_iterator
dynamodbstreams_get_shard_iterator <- function(StreamArn, ShardId, ShardIteratorType, SequenceNumber = NULL) {
  op <- new_operation(
    name = "GetShardIterator",
    http_method = "POST",
    http_path = "/",
    paginator = list()
  )
  input <- .dynamodbstreams$get_shard_iterator_input(StreamArn = StreamArn, ShardId = ShardId, ShardIteratorType = ShardIteratorType, SequenceNumber = SequenceNumber)
  output <- .dynamodbstreams$get_shard_iterator_output()
  config <- get_config()
  svc <- .dynamodbstreams$service(config)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.dynamodbstreams$operations$get_shard_iterator <- dynamodbstreams_get_shard_iterator

#' Returns an array of stream ARNs associated with the current account and
#' endpoint
#'
#' @description
#' Returns an array of stream ARNs associated with the current account and endpoint. If the `TableName` parameter is present, then [`list_streams`][dynamodbstreams_list_streams] will return only the streams ARNs for that table.
#'
#' See [https://www.paws-r-sdk.com/docs/dynamodbstreams_list_streams/](https://www.paws-r-sdk.com/docs/dynamodbstreams_list_streams/) for full documentation.
#'
#' @param TableName If this parameter is provided, then only the streams associated with
#' this table name are returned.
#' @param Limit The maximum number of streams to return. The upper limit is 100.
#' @param ExclusiveStartStreamArn The ARN (Amazon Resource Name) of the first item that this operation
#' will evaluate. Use the value that was returned for
#' `LastEvaluatedStreamArn` in the previous operation.
#'
#' @keywords internal
#'
#' @rdname dynamodbstreams_list_streams
dynamodbstreams_list_streams <- function(TableName = NULL, Limit = NULL, ExclusiveStartStreamArn = NULL) {
  op <- new_operation(
    name = "ListStreams",
    http_method = "POST",
    http_path = "/",
    paginator = list()
  )
  input <- .dynamodbstreams$list_streams_input(TableName = TableName, Limit = Limit, ExclusiveStartStreamArn = ExclusiveStartStreamArn)
  output <- .dynamodbstreams$list_streams_output()
  config <- get_config()
  svc <- .dynamodbstreams$service(config)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.dynamodbstreams$operations$list_streams <- dynamodbstreams_list_streams
