# This file is generated by make.paws. Please do not edit here.
#' @importFrom paws.common new_handlers new_service set_config merge_config
NULL

#' Redshift Data API Service
#'
#' @description
#' You can use the Amazon Redshift Data API to run queries on Amazon
#' Redshift tables. You can run SQL statements, which are committed if the
#' statement succeeds.
#' 
#' For more information about the Amazon Redshift Data API and CLI usage
#' examples, see [Using the Amazon Redshift Data
#' API](https://docs.aws.amazon.com/redshift/latest/mgmt/data-api.html) in
#' the *Amazon Redshift Management Guide*.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- redshiftdataapiservice(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- redshiftdataapiservice()
#' svc$batch_execute_statement(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[=redshiftdataapiservice_batch_execute_statement]{batch_execute_statement} \tab Runs one or more SQL statements, which can be data manipulation language (DML) or data definition language (DDL)\cr
#'  \link[=redshiftdataapiservice_cancel_statement]{cancel_statement} \tab Cancels a running query\cr
#'  \link[=redshiftdataapiservice_describe_statement]{describe_statement} \tab Describes the details about a specific instance when a query was run by the Amazon Redshift Data API\cr
#'  \link[=redshiftdataapiservice_describe_table]{describe_table} \tab Describes the detailed information about a table from metadata in the cluster\cr
#'  \link[=redshiftdataapiservice_execute_statement]{execute_statement} \tab Runs an SQL statement, which can be data manipulation language (DML) or data definition language (DDL)\cr
#'  \link[=redshiftdataapiservice_get_statement_result]{get_statement_result} \tab Fetches the temporarily cached result of an SQL statement\cr
#'  \link[=redshiftdataapiservice_list_databases]{list_databases} \tab List the databases in a cluster\cr
#'  \link[=redshiftdataapiservice_list_schemas]{list_schemas} \tab Lists the schemas in a database\cr
#'  \link[=redshiftdataapiservice_list_statements]{list_statements} \tab List of SQL statements\cr
#'  \link[=redshiftdataapiservice_list_tables]{list_tables} \tab List the tables in a database
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname redshiftdataapiservice
#' @export
redshiftdataapiservice <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  config <- merge_config(
    config,
    list(
      credentials = credentials,
      endpoint = endpoint,
      region = region
    )
  )
  svc <- .redshiftdataapiservice$operations
  svc <- set_config(svc, config)
  return(svc)
}

# Private API objects: metadata, handlers, interfaces, etc.
.redshiftdataapiservice <- list()

.redshiftdataapiservice$operations <- list()

.redshiftdataapiservice$metadata <- list(
  service_name = "redshiftdataapiservice",
  endpoints = list("*" = list(endpoint = "redshift-data.{region}.amazonaws.com", global = FALSE), "cn-*" = list(endpoint = "redshift-data.{region}.amazonaws.com.cn", global = FALSE), "us-iso-*" = list(endpoint = "redshift-data.{region}.c2s.ic.gov", global = FALSE), "us-isob-*" = list(endpoint = "redshift-data.{region}.sc2s.sgov.gov", global = FALSE)),
  service_id = "Redshift Data",
  api_version = "2019-12-20",
  signing_name = "redshift-data",
  json_version = "1.1",
  target_prefix = "RedshiftData"
)

.redshiftdataapiservice$service <- function(config = list()) {
  handlers <- new_handlers("jsonrpc", "v4")
  new_service(.redshiftdataapiservice$metadata, handlers, config)
}
